@@ -134,6 +134,7 @@ module java.base {
     exports com.ibm.oti.util to
         java.management,
         jdk.attach,
+        jdk.jcmd,
         jdk.management,
         openj9.sharedclasses;
     exports com.ibm.oti.vm to
@@ -146,7 +147,10 @@ module java.base {
         java.management,
         java.rmi,
         openj9.sharedclasses;
-    exports com.ibm.tools.attach.target to jdk.attach;
+    exports com.ibm.tools.attach.target to
+        jdk.attach,
+        jdk.jcmd,
+        jdk.management;
     exports com.sun.security.ntlm to java.security.sasl;
     exports jdk.internal to jdk.jfr;
     exports jdk.internal.jimage to jdk.jlink;
@@ -230,6 +234,10 @@ module java.base {
     exports jdk.internal.vm.annotation to
         jdk.internal.vm.ci,
         jdk.unsupported;
+    exports openj9.tools.attach.diagnostics.base to jdk.jcmd;
+    exports openj9.tools.attach.diagnostics.spi to
+        jdk.attach,
+        jdk.jcmd;
     exports sun.net to
         java.net.http,
         jdk.naming.dns;
@@ -349,6 +357,7 @@ module java.base {
     uses java.util.spi.ToolProvider;
     uses javax.security.auth.spi.LoginModule;
     uses jdk.internal.logger.DefaultLoggerFinder;
+    uses openj9.tools.attach.diagnostics.spi.TargetDiagnosticsProvider;
     uses sun.text.spi.JavaTimeDateTimePatternProvider;
     uses sun.util.locale.provider.LocaleDataMetaInfo;
     uses sun.util.resources.LocaleData.CommonResourceBundleProvider;
